# Directory `tests`

To store modules testing the project's code.
Sub directory names are in line with package and module names
as given in the directory `jarpyvscode`.

Test data belongs into folders with names in line to test modules.
When there is a `test_foo.py`, test data belonging to that test
module is located in a neighbouring folder `test_foo`.
